@@ -8,7 +8,7 @@ from xml.etree import cElementTree as ElementTree
 
 import xmltodict
 
-from .consts import CONFIG, LOGS, AIRTEL_MONEY, REDIS_DB, IzyTV, TODAY_STR
+from .consts import CONFIG, LOGS, AIRTEL_MONEY, REDIS_DB, IzyTV
 from .xmlparser import XmlDictConfig
 
 
@@ -116,7 +116,7 @@ class AirtelMoney(object):
         LOGS.logger.info(
             "[AirtelMoney][{}] Writing to Redis...\n\n".format(operation_id)
         )
-        today = TODAY_STR
+        today = datetime.today().strftime("%Y-%m-%d %H:%M:%S")
         re_data = {
             "TransactionDate": today,
             "amount": data["amount"],
