@@ -62,7 +62,6 @@ def internal_server_error(e):
     )
 
 from . import mvola  # NOQA
-from . import orangemoney # NOQA
-from . import sage # NOQA
-
+from . import orangemoney  # NOQA
+from . import airtelmoney  # NOQA
 # EOF
