@@ -34,4 +34,16 @@ def OrangecheckRedis():
     orangemoney = OrangeMoney()
     response = orangemoney.checkTransactionStatusRedis(data["operation_id"])
     return jsonify(response)
+
+
+@api.route("/orangemoney/updateRefPartner", methods=["POST"])
+def OrangeUpdateRefPartner():
+    """
+    Pour Checker le status de la transaction
+    """
+    transaction = request.get_json()
+    LOGS.logger.info("\n\nCheck ORANGEMONEY transaction status\n\n")
+    orangemoney = OrangeMoney()
+    response = orangemoney.updateRefPartner(transaction)
+    return jsonify(response)
 # EOF
